summaryrefslogtreecommitdiff
path: root/python/function.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/function.py')
-rw-r--r--python/function.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/python/function.py b/python/function.py
index 0bbd0a99..8c4fe265 100644
--- a/python/function.py
+++ b/python/function.py
@@ -855,12 +855,12 @@ class Function(object):
@property
def highest_address(self):
- "The highest virtual address in a function."""
- return max(self, key=lambda block:block.end).end
+ "The highest virtual address contained in a function."""
+ return max(self, key=lambda block:block.end).end - 1
@property
def lowest_address(self):
"""The lowest virtual address in a function."""
return min(self, key=lambda block:block.start).start
@property
@@ -855,12 +855,12 @@ class Function(object):
def lowest_address(self):
- """The lowest virtual address in a function."""
+ """The lowest virtual address contained in a function."""
return min(self, key=lambda block:block.start).start